require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_cmsitemaintenance',
  dscmeta_resource_friendly_name: 'CMSiteMaintenance',
  dscmeta_resource_name: 'DSC_CMSiteMaintenance',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'ConfigMgrCBDsc',
  dscmeta_module_version: '3.0.0',
  docs: 'The DSC CMSiteMaintenance resource type.
         Automatically generated from version 3.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_tasktype: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the type of task',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_latestbegintime: {
      type: 'Optional[String]',
      desc: 'Specifies the latest start time at which the maintenance task runs.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_daysofweek: {
      type: "Optional[Array[Enum['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday']]]",
      desc: 'Specifies an array of day names that determine the days of each week on which the maintenance task runs',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_deleteolderthandays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how many days to delete data that has been inactive for.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_sitetype: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the a numeric value for the site type.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_backuplocation: {
      type: 'Optional[String]',
      desc: 'Specifies the backup location for Backup Site Server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitecode: {
      type: 'String',
      desc: 'Specifies the SiteCode for the Configuration Manager site.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_taskname: {
      type: "Enum['Delete Aged Inventory History', 'Delete Aged Metering Data', 'Clear Undiscovered Clients', 'Delete Obsolete Alerts', 'Delete Aged Replication Data', 'Delete Aged Device Wipe Record', 'Delete Aged Enrolled Devices', 'Delete Aged User Device Affinity Data', 'Delete Duplicate System Discovery Data', 'Delete Aged Unknown Computers', 'Delete Expired MDM Bulk Enroll Package Records', 'Backup SMS Site Server', 'Delete Aged Status Messages', 'Delete Aged Metering Summary Data', 'Delete Inactive Client Discovery Data', 'Delete Aged Application Revisions', 'Delete Aged Replication Summary Data', 'Delete Obsolete Forest Discovery Sites And Subnets', 'Delete Aged Threat Data', 'Delete Aged Delete Detection Data', 'Delete Aged Distribution Point Usage Stats', 'Delete Orphaned Client Deployment State Records', 'Rebuild Indexes', 'Delete Aged Discovery Data', 'Summarize File Usage Metering Data', 'Delete Obsolete Client Discovery Data', 'Delete Aged Log Data', 'Delete Aged Application Request Data', 'Check Application Title with Inventory Information', 'Delete Aged EP Health Status History Data', 'Delete Aged Notification Task History', 'Delete Aged Passcode Records', 'Delete Aged Console Connection Data', 'Monitor Keys', 'Delete Aged Collected Files', 'Summarize Monthly Usage Metering Data', 'Delete Aged Computer Association Data', 'Delete Aged Client Download History', 'Delete Aged Exchange Partnership', 'Summarize Installed Software Data', 'Delete Aged Client Operations', 'Delete Aged Notification Server History', 'Update Application Available Targeting', 'Delete Aged Cloud Management Gateway Traffic Data', 'Update Application Catalog Tables']",
      desc: 'Specifies the parent setting category.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_runinterval: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the run interval in minutes for the task.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_begintime: {
      type: 'Optional[String]',
      desc: 'Specifies the time at which a maintenance task starts.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: 'Boolean',
      desc: 'Specifies if the task is enabled or disabled.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
